==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/type_test/xml/TestAnyURIEnumResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.AnyURIEnum;


/**
 * <p>Java class for testAnyURIEnumResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testAnyURIEnumResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testAnyURIEnumResponse")
public class TestAnyURIEnumResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/xml", required = true)
    protected AnyURIEnum _return;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected AnyURIEnum y;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected AnyURIEnum z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setReturn(AnyURIEnum value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setY(AnyURIEnum value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setZ(AnyURIEnum value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/xml/TestAnyURIEnumResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.AnyURIEnum;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types1}AnyURIEnum"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testAnyURIEnumResponse")
public class TestAnyURIEnumResponse {

    @XmlElement(name = "return", required = true)
    protected AnyURIEnum _return;
    @XmlElement(required = true)
    protected AnyURIEnum y;
    @XmlElement(required = true)
    protected AnyURIEnum z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setReturn(AnyURIEnum value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setY(AnyURIEnum value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link AnyURIEnum }
     *     
     */
    public AnyURIEnum getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyURIEnum }
     *     
     */
    public void setZ(AnyURIEnum value) {
        this.z = value;
    }

}
